@@ -1167,7 +1167,9 @@ void FolderModel::dragSelectedInternal(int x, int y)
     DragTracker::self()->setDragInProgress(nullptr, false);
     m_urlChangedWhileDragging = false;
 
-    if (m_dirModel->dirLister()->url() == currentUrl) {
+    // If we spring-load into another folder and back (with the back button or draggin outside a popup)
+    // the first condition will be true, but we don't want to do this with an empty dragIndexes
+    if (m_dirModel->dirLister()->url() == currentUrl && !m_dragIndexes.isEmpty()) {
         const QModelIndex first(m_dragIndexes.first());
         const QModelIndex last(m_dragIndexes.last());
         m_dragIndexes.clear();
@@ -1230,10 +1232,9 @@ void FolderModel::drop(QQuickItem *target, QObject *dropEvent, int row, bool sho
         dropTargetUrl = item.mostLocalUrl();
     }
 
-    auto dropTargetFolderUrl = dropTargetUrl;
-    if (dropTargetFolderUrl.fileName() == QLatin1Char('.')) {
+    if (dropTargetUrl.fileName() == QLatin1Char('.')) {
         // the target URL for desktop:/ is e.g. 'file://home/user/Desktop/.'
-        dropTargetFolderUrl = dropTargetFolderUrl.adjusted(QUrl::RemoveFilename);
+        dropTargetUrl = dropTargetUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
     }
 
     // use dropTargetUrl to resolve desktop:/ to the actual file location which is also used by the mime data
@@ -1241,10 +1242,10 @@ void FolderModel::drop(QQuickItem *target, QObject *dropEvent, int row, bool sho
      * use a fancy scheme like desktop:/ instead. Ensure we always use the latter to properly map URLs,
      * i.e. go from file:///home/user/Desktop/file to desktop:/file
      */
-    auto mappableUrl = [this, dropTargetFolderUrl](const QUrl &url) -> QUrl {
-        if (dropTargetFolderUrl != m_dirModel->dirLister()->url()) {
+    auto mappableUrl = [this, dropTargetUrl](const QUrl &url) -> QUrl {
+        if (dropTargetUrl != m_dirModel->dirLister()->url()) {
             QString mappedUrl = url.toString();
-            const auto local = dropTargetFolderUrl.toString();
+            const auto local = dropTargetUrl.toString();
             const auto internal = m_dirModel->dirLister()->url().toString();
             if (mappedUrl.startsWith(local)) {
                 mappedUrl.replace(0, local.size(), internal);
@@ -1286,7 +1287,7 @@ void FolderModel::drop(QQuickItem *target, QObject *dropEvent, int row, bool sho
     }
 
     if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
-        if (isDropBetweenSharedViews(mimeData->urls(), dropTargetFolderUrl)) {
+        if (isDropBetweenSharedViews(mimeData->urls(), dropTargetUrl)) {
             setUnsortedModeOnDrop();
             const QList<QUrl> urls = mimeData->urls();
             for (const auto &url : urls) {
